@@ -3,7 +3,7 @@ import logging
 
 from PlanetProfile.Thermodynamics.IronCore import IronCoreLayers
 from PlanetProfile.Thermodynamics.HydroEOS import GetPfreeze, GetTfreeze, \
-    PhaseConv, GetPhaseIndices, GetIceEOS, GetPbClath, GetOceanEOS
+    PhaseConv, GetPhaseIndices, GetIceEOS, GetOceanEOS
 from PlanetProfile.Thermodynamics.InnerEOS import GetHtidalFunc, GetphiCalc
 from PlanetProfile.Thermodynamics.Silicates import SilicateLayers
 from PlanetProfile.Thermodynamics.ThermalProfiles.Convection import IceIConvectSolid, IceIConvectPorous, \
@@ -44,7 +44,7 @@ def IceLayers(Planet, Params):
     if(Planet.Do.CLATHRATE and
             (Planet.Bulk.clathType == 'bottom' or
              Planet.Bulk.clathType == 'whole')):
-        PbClath_MPa = GetPbClath(Planet.Bulk.Tb_K)
+        PbClath_MPa = Planet.Ocean.ClathDissoc.PbClath_MPa()
         if not np.isnan(PbClath_MPa):
             log.debug(f'Clathrate dissociation pressure: {PbClath_MPa:.3f} MPa.')
             if PbClath_MPa < Planet.PbI_MPa:
@@ -243,7 +243,7 @@ def IceLayers(Planet, Params):
                 Planet.etaConv_Pas = np.nan
             else:
                 Pbot_MPa = np.arange(Planet.PfreezeLower_MPa, Planet.PfreezeUpper_MPa, Planet.PfreezeRes_MPa)
-                Tbot_K = np.arange(Planet.T_K[Planet.Steps.nIceI], 273, 0.5)
+                Tbot_K = np.arange(Planet.T_K[Planet.Steps.nIceI], np.maximum(273, Planet.T_K[Planet.Steps.nIceI]+20), 0.5)
                 iceImeltEOS = GetOceanEOS('PureH2O', 0.0, Pbot_MPa, Tbot_K, None,
                                           phaseType=Planet.Ocean.phaseType, FORCE_NEW=True)
                 Planet.Tconv_K, Planet.etaConv_Pas, _, _, _, _, Planet.RaConvect, Planet.RaCrit \
@@ -1135,7 +1135,7 @@ def CalcMoIWithEOS(Planet, Params):
         nSilFinal = Planet.Steps.nSilMax * np.ones_like(indsSilValid).astype(np.int_)
         Ccore_kgm2 = 0
 
-        C_kgm2 = np.zeros(Planet.Steps.iSilStart + Planet.Steps.nSilMax)
+        C_kgm2 = np.zeros(Planet.Steps.nHydroMax)
 
     # Find contribution to axial moment of inertia C from each silicate layer
     dCfromSil_kgm2 = 8*np.pi/15 * rhoSil_kgm3 * (rSil_m[:,:-1]**5 - rSil_m[:,1:]**5)
@@ -1233,9 +1233,16 @@ def CalcMoIWithEOS(Planet, Params):
             Planet.CMR2less = np.nan
             Planet.CMR2more = np.nan
         else:
-            CMR2neighbors = [CMR2[iCMR2-1], CMR2[iCMR2+1]]
-            Planet.CMR2less = np.min(CMR2neighbors)
-            Planet.CMR2more = np.max(CMR2neighbors)
+            CMR2validSorted = np.sort(CMR2[CMR2inds])
+            iSortedCMR2mean = np.where(CMR2validSorted == Planet.CMR2mean)[0][0]
+            if iSortedCMR2mean == 0:
+                Planet.CMR2less = Planet.CMR2mean
+            else:
+                Planet.CMR2less = CMR2validSorted[iSortedCMR2mean-1]
+            if iSortedCMR2mean == np.size(CMR2validSorted) - 1:
+                Planet.CMR2more = Planet.CMR2mean
+            else:
+                Planet.CMR2more = CMR2validSorted[iSortedCMR2mean+1]
         # Now we finally know how many layers there are in the hydrosphere and silicates
         Planet.Steps.nHydro = iCMR2
         Planet.Steps.nSil = nSilFinal[iCMR2sil]
